@@ -7,7 +7,7 @@ let package = Package(
     .library(name: "TreeSitterPHP", targets: ["TreeSitterPHP"]),
   ],
   dependencies: [
-    .package(url: "https://github.com/ChimeHQ/SwiftTreeSitter", from: "0.8.0"),
+    .package(url: "https://github.com/tree-sitter/swift-tree-sitter", from: "0.9.0"),
   ],
   targets: [
     .target(
@@ -28,7 +28,7 @@ let package = Package(
     .testTarget(
       name: "TreeSitterPHPTests",
       dependencies: [
-        "SwiftTreeSitter",
+        .product(name: "SwiftTreeSitter", package: "swift-tree-sitter"),
         "TreeSitterPHP",
       ],
       path: "bindings/swift/TreeSitterPHPTests"
